@@ -4,6 +4,12 @@
 
 -- | This is the simplest implementation of thread-local storage using
 -- GHC's built-in ThreadId capabilities.
+--
+-- While the interface below is designed to match the other
+-- implementations of TLS in this package, the GHC implementation can
+-- generaly be relied upon to keep a stable copy of the TLS variable
+-- for each `ThreadId` that calls `getTLS`.  This may change in the
+-- future, however!
 
 module Data.TLS.GHC
     ( TLS
@@ -11,11 +17,12 @@ module Data.TLS.GHC
     , getTLS
     , allTLS
     , forEachTLS_
+    , freeAllTLS
+    -- * Deprecated, backwards compatibility
     , freeTLS
     ) where
 
 import Control.Monad
-import Control.Exception (evaluate)
 import Control.Concurrent
 import Data.Map.Strict as M
 import Data.IORef
@@ -54,5 +61,6 @@ forEachTLS_ tls fn = do
   forM_ ls fn 
 
 -- Nothing to do here... we haven't pinned anything.  Normal GC is fine.
-freeTLS _ = return ()
+freeAllTLS _ =
+  do return ()
 
